netapp_ontap.models.volume_quota API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.volume_quota`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class VolumeQuotaSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the VolumeQuota object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `enabled PATCH`

    This option is used to enable or disable the quota for the volume. This option is valid only in PATCH. Quotas are enabled for FlexVols or FlexGroup volumes when the quota state is "on". Quotas are disabled for FlexVols or FlexGroup volumes when the quota state is "off".

  `state GET`

    Quota state of the volume

    Valid choices:

    - corrupt
    - initializing
    - mixed
    - off
    - on
    - resizing